==> haskell-transformers-base-0.4.4-5-i686.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.4
id: transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
key: transformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
license: BSD3
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Base
abi: fb06f85bedde83d35afe68c1ca003136
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/transformers-base-0.4.4
library-dirs: /usr/lib/ghc-8.0.1/site-local/transformers-base-0.4.4
data-dir: /usr/share/i386-linux-ghc-8.0.1/transformers-base-0.4.4
hs-libraries: HStransformers-base-0.4.4-LWS58Nywv1PJoy1IFDbvS4
depends:
    base-4.9.0.0 stm-2.4.4.1-9HlGYelGmT69YkepeDjuRg
    transformers-0.5.2.0
    transformers-compat-0.5.1.4-81lZyuOJOvsD0zyCv2TKld
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-base-0.4.4-6-i686.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-base.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-base
version: 0.4.4
id: transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
key: transformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
license: BSD3
copyright: 2011 Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
           Bas van Dijk <v.dijk.bas@gmail.com>
maintainer: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>
stability: experimental
homepage: https://github.com/mvv/transformers-base
synopsis: Lift computations from the bottom of a transformer stack
description:
    This package provides a straightforward port of @monadLib@'\''s BaseM
    typeclass to @transformers@.
category: Control
author: Mikhail Vorozhtsov <mikhail.vorozhtsov@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
exposed: True
exposed-modules:
    Control.Monad.Base
abi: 17e69075f6ad2b9e44351d072837fb6d
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/transformers-base-0.4.4
library-dirs: /usr/lib/ghc-8.0.2/site-local/transformers-base-0.4.4
dynamic-library-dirs: /usr/lib/i386-linux-ghc-8.0.2
data-dir: /usr/share/i386-linux-ghc-8.0.2/transformers-base-0.4.4
hs-libraries: HStransformers-base-0.4.4-H3XecnBtTa65CX4xecxCVH
depends:
    base-4.9.1.0 stm-2.4.4.1-iSYwp3RMY11sHCifJ3gtR transformers-0.5.2.0
    transformers-compat-0.5.1.4-IuFogs8HAVUJBWVNMhtssu
haddock-interfaces: /usr/share/doc/haskell-transformers-base/html/transformers-base.haddock
haddock-html: /usr/share/doc/haskell-transformers-base/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
